@@ -4,6 +4,8 @@ import os
 import tarfile
 import tempfile
 
+import dask.dataframe as dd
+
 from featuretools.utils.s3_utils import get_transport_params, use_smartopen_es
 from featuretools.utils.wrangle import _is_s3, _is_url
 
@@ -22,6 +24,10 @@ def entity_to_description(entity):
     '''
     index = entity.df.columns.isin([variable.id for variable in entity.variables])
     dtypes = entity.df[entity.df.columns[index]].dtypes.astype(str).to_dict()
+    if isinstance(entity.df, dd.DataFrame):
+        entity_type = 'dask'
+    else:
+        entity_type = 'pandas'
     description = {
         "id": entity.id,
         "index": entity.index,
@@ -32,6 +38,7 @@ def entity_to_description(entity):
         },
         "variables": [variable.to_data_description() for variable in entity.variables],
         "loading_info": {
+            'entity_type': entity_type,
             'params': {},
             'properties': {
                 'dtypes': dtypes
@@ -76,11 +83,16 @@ def write_entity_data(entity, path, format='csv', **kwargs):
         loading_info (dict) : Information on storage location and format of entity data.
     '''
     format = format.lower()
-    basename = '.'.join([entity.id, format])
+    if isinstance(entity.df, dd.DataFrame) and format == 'csv':
+        basename = "{}-*.{}".format(entity.id, format)
+    else:
+        basename = '.'.join([entity.id, format])
     location = os.path.join('data', basename)
     file = os.path.join(path, location)
+    df = entity.df
+
     if format == 'csv':
-        entity.df.to_csv(
+        df.to_csv(
             file,
             index=kwargs['index'],
             sep=kwargs['sep'],
@@ -91,12 +103,17 @@ def write_entity_data(entity, path, format='csv', **kwargs):
         # Serializing to parquet format raises an error when columns contain tuples.
         # Columns containing tuples are mapped as dtype object.
         # Issue is resolved by casting columns of dtype object to string.
-        df = entity.df.copy()
-        columns = df.select_dtypes('object').columns
+        df = df.copy()
+        columns = list(df.select_dtypes('object').columns)
         df[columns] = df[columns].astype('unicode')
         df.to_parquet(file, **kwargs)
     elif format == 'pickle':
-        entity.df.to_pickle(file, **kwargs)
+        # Dask currently does not support to_pickle
+        if isinstance(df, dd.DataFrame):
+            msg = 'Cannot serialize Dask EntitySet to pickle'
+            raise ValueError(msg)
+        else:
+            df.to_pickle(file, **kwargs)
     else:
         error = 'must be one of the following formats: {}'
         raise ValueError(error.format(', '.join(FORMATS)))
