@@ -38,7 +38,7 @@ class IsNull(TransformPrimitive):
             if isinstance(array, dd.Series):
                 return dd.Series.isnull(array)
             else:
-                return pd.isnull(pd.Series(array))
+                return pd.isnull(array)
         return isnull
 
 
@@ -115,9 +115,7 @@ class Day(TransformPrimitive):
 
     def get_function(self):
         def day(vals):
-            if isinstance(vals, dd.Series):
-                return vals.dt.day
-            return pd.DatetimeIndex(vals).day.values
+            return vals.dt.day
         return day
 
 
@@ -140,9 +138,7 @@ class Hour(TransformPrimitive):
 
     def get_function(self):
         def hour(vals):
-            if isinstance(vals, dd.Series):
-                return vals.dt.hour
-            return pd.DatetimeIndex(vals).hour.values
+            return vals.dt.hour
         return hour
 
 
@@ -165,9 +161,7 @@ class Second(TransformPrimitive):
 
     def get_function(self):
         def second(vals):
-            if isinstance(vals, dd.Series):
-                return vals.dt.second
-            return pd.DatetimeIndex(vals).second.values
+            return vals.dt.second
         return second
 
 
@@ -190,9 +184,7 @@ class Minute(TransformPrimitive):
 
     def get_function(self):
         def minute(vals):
-            if isinstance(vals, dd.Series):
-                return vals.dt.minute
-            return pd.DatetimeIndex(vals).minute.values
+            return vals.dt.minute
         return minute
 
 
@@ -220,9 +212,7 @@ class Week(TransformPrimitive):
 
     def get_function(self):
         def week(vals):
-            if isinstance(vals, dd.Series):
-                return vals.dt.week
-            return pd.DatetimeIndex(vals).week.values
+            return vals.dt.week
         return week
 
 
@@ -245,9 +235,7 @@ class Month(TransformPrimitive):
 
     def get_function(self):
         def month(vals):
-            if isinstance(vals, dd.Series):
-                return vals.dt.month
-            return pd.DatetimeIndex(vals).month.values
+            return vals.dt.month
         return month
 
 
@@ -270,9 +258,7 @@ class Year(TransformPrimitive):
 
     def get_function(self):
         def year(vals):
-            if isinstance(vals, dd.Series):
-                return vals.dt.year
-            return pd.DatetimeIndex(vals).year.values
+            return vals.dt.year
         return year
 
 
@@ -295,9 +281,7 @@ class IsWeekend(TransformPrimitive):
 
     def get_function(self):
         def is_weekend(vals):
-            if isinstance(vals, dd.Series):
-                return vals.dt.weekday > 4
-            return pd.DatetimeIndex(vals).weekday.values > 4
+            return vals.dt.weekday > 4
         return is_weekend
 
 
@@ -324,9 +308,7 @@ class Weekday(TransformPrimitive):
 
     def get_function(self):
         def weekday(vals):
-            if isinstance(vals, dd.Series):
-                return vals.dt.weekday
-            return pd.DatetimeIndex(vals).weekday.values
+            return vals.dt.weekday
         return weekday
 
 
@@ -388,7 +370,7 @@ class TimeSince(TransformPrimitive):
         ...          datetime(2019, 3, 1, 0, 0, 1, 0),
         ...          datetime(2019, 3, 1, 0, 2, 0, 0)]
         >>> cutoff_time = datetime(2019, 3, 1, 0, 0, 0, 0)
-        >>> values = time_since(array=times, time=cutoff_time)
+        >>> values = time_since(times, time=cutoff_time)
         >>> list(map(int, values))
         [0, -1, -120]
 
@@ -400,7 +382,7 @@ class TimeSince(TransformPrimitive):
         ...          datetime(2019, 3, 1, 0, 0, 1, 0),
         ...          datetime(2019, 3, 1, 0, 2, 0, 0)]
         >>> cutoff_time = datetime(2019, 3, 1, 0, 0, 0, 0)
-        >>> values = time_since_nano(array=times, time=cutoff_time)
+        >>> values = time_since_nano(times, time=cutoff_time)
         >>> list(map(lambda x: int(round(x)), values))
         [-1000, -1000000000, -120000000000]
     """
@@ -415,8 +397,6 @@ class TimeSince(TransformPrimitive):
 
     def get_function(self):
         def pd_time_since(array, time):
-            if isinstance(array, list):
-                array = pd.Series(array)
             return convert_time_units((time - array).dt.total_seconds(), self.unit)
         return pd_time_since
 
@@ -440,10 +420,7 @@ class IsIn(TransformPrimitive):
 
     def get_function(self):
         def pd_is_in(array):
-            if isinstance(array, dd.Series):
-                return array.isin(self.list_of_outputs or [])
-            else:
-                return pd.Series(array).isin(self.list_of_outputs or [])
+            return array.isin(self.list_of_outputs or [])
         return pd_is_in
 
     def generate_name(self, base_feature_names):
@@ -539,7 +516,7 @@ class Percentile(TransformPrimitive):
     return_type = Numeric
 
     def get_function(self):
-        return lambda array: pd.Series(array).rank(pct=True)
+        return lambda array: array.rank(pct=True)
 
 
 class Latitude(TransformPrimitive):
@@ -561,7 +538,7 @@ class Latitude(TransformPrimitive):
         def latitude(latlong):
             if latlong.hasnans:
                 latlong = replace_latlong_nan(latlong)
-            return pd.Series(x[0] for x in latlong)
+            return latlong.map(lambda x: x[0])
         return latitude
 
 
@@ -584,7 +561,7 @@ class Longitude(TransformPrimitive):
         def longitude(latlong):
             if latlong.hasnans:
                 latlong = replace_latlong_nan(latlong)
-            return pd.Series(x[1] for x in latlong)
+            return latlong.map(lambda x: x[1])
         return longitude
 
 
