@@ -91,7 +91,7 @@ def test_calc_feature_matrix(es):
         feature_matrix = calculate_feature_matrix([1, 2, 3], es, cutoff_time=cutoff_time)
 
     error_text = "cutoff_time times must be datetime type: try casting via "\
-        "pd\\.to_datetime\\(cutoff_time\\['time'\\]\\)"
+        "pd\\.to_datetime\\(\\)"
     with pytest.raises(TypeError, match=error_text):
         calculate_feature_matrix([property_feature],
                                  es,
@@ -128,7 +128,7 @@ def test_calc_feature_matrix(es):
     # - can't tell if wrong/different all are false so can't check positional
 
 
-def test_cfm_fails_dask_cutoff_time(es):
+def test_cfm_warns_dask_cutoff_time(es):
     times = list([datetime(2011, 4, 9, 10, 30, i * 6) for i in range(5)] +
                  [datetime(2011, 4, 9, 10, 31, i * 9) for i in range(4)] +
                  [datetime(2011, 4, 9, 10, 40, 0)] +
@@ -142,9 +142,9 @@ def test_cfm_fails_dask_cutoff_time(es):
 
     property_feature = ft.Feature(es['log']['value']) > 10
 
-    error_text = "cannot use Dask DataFrame for cutoff_time: "\
-                 "cutoff_time must a single value or a Pandas DataFrame"
-    with pytest.raises(TypeError, match=error_text):
+    match = "cutoff_time should be a Pandas DataFrame: " \
+            "computing cutoff_time, this may take a while"
+    with pytest.warns(UserWarning, match=match):
         calculate_feature_matrix([property_feature],
                                  es,
                                  cutoff_time=cutoff_time)
@@ -459,6 +459,8 @@ def test_training_window(pd_es):
     top_level_agg = ft.Feature(pd_es['customers']['id'], parent_entity=pd_es[u'régions'], primitive=Count)
 
     # make sure features that have a direct to a higher level agg
+    # so we have multiple "filter eids" in get_pandas_data_slice,
+    # and we go through the loop to pull data with a training_window param more than once
     dagg = DirectFeature(top_level_agg, pd_es['customers'])
 
     # for now, warns if last_time_index not present
@@ -499,6 +501,29 @@ def test_training_window(pd_es):
                                               include_cutoff_time=False)
     prop_values = [5, 5, 2]
     dagg_values = [3, 2, 1]
+
+    assert (feature_matrix[property_feature.get_name()] == prop_values).values.all()
+    assert (feature_matrix[dagg.get_name()] == dagg_values).values.all()
+
+    # Case3. include_cutoff_time = False with single cutoff time value
+    feature_matrix = calculate_feature_matrix([property_feature, dagg],
+                                              pd_es,
+                                              cutoff_time=pd.to_datetime("2011-04-09 10:40:00"),
+                                              training_window='9 minutes',
+                                              include_cutoff_time=False)
+    prop_values = [0, 4, 0]
+    dagg_values = [3, 3, 3]
+    assert (feature_matrix[property_feature.get_name()] == prop_values).values.all()
+    assert (feature_matrix[dagg.get_name()] == dagg_values).values.all()
+
+    # Case4. include_cutoff_time = True with single cutoff time value
+    feature_matrix = calculate_feature_matrix([property_feature, dagg],
+                                              pd_es,
+                                              cutoff_time=pd.to_datetime("2011-04-10 10:40:00"),
+                                              training_window='2 days',
+                                              include_cutoff_time=True)
+    prop_values = [0, 10, 1]
+    dagg_values = [3, 3, 3]
     assert (feature_matrix[property_feature.get_name()] == prop_values).values.all()
     assert (feature_matrix[dagg.get_name()] == dagg_values).values.all()
 
@@ -574,6 +599,28 @@ def test_include_cutoff_time_without_training_window(es):
     )['COUNT(log)']
     np.testing.assert_array_equal(actual.values, [0, 5])
 
+    # Case3. include_cutoff_time = True with single cutoff time value
+    actual = ft.calculate_feature_matrix(
+        features=[count_log],
+        entityset=es,
+        cutoff_time=pd.to_datetime("2011-04-09 10:31:00"),
+        instance_ids=[0],
+        cutoff_time_in_index=True,
+        include_cutoff_time=True,
+    )['COUNT(log)']
+    np.testing.assert_array_equal(actual.values, [6])
+
+    # Case4. include_cutoff_time = False with single cutoff time value
+    actual = ft.calculate_feature_matrix(
+        features=[count_log],
+        entityset=es,
+        cutoff_time=pd.to_datetime("2011-04-09 10:31:00"),
+        instance_ids=[0],
+        cutoff_time_in_index=True,
+        include_cutoff_time=False,
+    )['COUNT(log)']
+    np.testing.assert_array_equal(actual.values, [5])
+
 
 def test_approximate_dfeat_of_agg_on_target_include_cutoff_time(pd_es):
     agg_feat = ft.Feature(pd_es['log']['id'], parent_entity=pd_es['sessions'], primitive=Count)
@@ -1328,14 +1375,28 @@ def test_integer_time_index(int_es):
     assert (feature_matrix[property_feature.get_name()] == labels).values.all()
 
 
+def test_integer_time_index_single_cutoff_value(int_es):
+    labels = [False] * 3 + [True] * 2 + [False] * 4
+    property_feature = IdentityFeature(int_es['log']['value']) > 10
+
+    cutoff_times = [16, pd.Series([16])[0], 16.0, pd.Series([16.0])[0]]
+    for cutoff_time in cutoff_times:
+        feature_matrix = calculate_feature_matrix([property_feature],
+                                                  int_es,
+                                                  cutoff_time=cutoff_time,
+                                                  cutoff_time_in_index=True)
+        time_level_vals = feature_matrix.index.get_level_values(1).values
+        assert (time_level_vals == [16] * 9).all()
+        assert (feature_matrix[property_feature.get_name()] == labels).values.all()
+
+
 # TODO: add dask version of int_es
 def test_integer_time_index_datetime_cutoffs(int_es):
     times = [datetime.now()] * 17
     cutoff_df = pd.DataFrame({'time': times, 'instance_id': range(17)})
     property_feature = IdentityFeature(int_es['log']['value']) > 10
 
-    error_text = "cutoff_time times must be numeric: try casting via "\
-        "pd\\.to_numeric\\(cutoff_time\\['time'\\]\\)"
+    error_text = "cutoff_time times must be numeric: try casting via pd\\.to_numeric\\(\\)"
     with pytest.raises(TypeError, match=error_text):
         calculate_feature_matrix([property_feature],
                                  int_es,
@@ -1632,6 +1693,18 @@ def test_calls_progress_callback(mock_customer):
     assert np.isclose(mock_progress_callback.total_update, 100.0)
     assert np.isclose(mock_progress_callback.total_progress_percent, 100.0)
 
+    # test with cutoff time dataframe
+    mock_progress_callback = MockProgressCallback()
+    cutoff_time = pd.DataFrame({"instance_id": [1, 2, 3],
+                                "time": [pd.to_datetime("2014-01-01 01:00:00"),
+                                         pd.to_datetime("2014-01-01 02:00:00"),
+                                         pd.to_datetime("2014-01-01 03:00:00")]})
+
+    ft.calculate_feature_matrix(features, entityset=es, cutoff_time=cutoff_time, progress_callback=mock_progress_callback)
+    assert np.isclose(mock_progress_callback.progress_history[-2], FEATURE_CALCULATION_PERCENTAGE * 100)
+    assert np.isclose(mock_progress_callback.total_update, 100.0)
+    assert np.isclose(mock_progress_callback.total_progress_percent, 100.0)
+
     # test with multiple jobs, pandas only
     if any(isinstance(entity.df, pd.DataFrame) for entity in es.entities):
         mock_progress_callback = MockProgressCallback()
@@ -1679,3 +1752,60 @@ def test_closes_tqdm(es):
         assert e.args[0] == "This primitive has errored"
     finally:
         assert len(tqdm._instances) == 0
+
+
+def test_approximate_with_single_cutoff_warns(pd_es):
+    features = dfs(entityset=pd_es,
+                   target_entity='customers',
+                   features_only=True,
+                   ignore_entities=['cohorts'],
+                   agg_primitives=['sum'])
+
+    match = "Using approximate with a single cutoff_time value or no cutoff_time " \
+        "provides no computational efficiency benefit"
+    # test warning with single cutoff time
+    with pytest.warns(UserWarning, match=match):
+        calculate_feature_matrix(features,
+                                 pd_es,
+                                 cutoff_time=pd.to_datetime("2020-01-01"),
+                                 approximate="1 day")
+    # test warning with no cutoff time
+    with pytest.warns(UserWarning, match=match):
+        calculate_feature_matrix(features,
+                                 pd_es,
+                                 approximate="1 day")
+
+    # check proper handling of approximate
+    feature_matrix = calculate_feature_matrix(features,
+                                              pd_es,
+                                              cutoff_time=pd.to_datetime("2011-04-09 10:31:30"),
+                                              approximate="1 minute")
+
+    expected_values = [50, 50, 50]
+    assert (feature_matrix['régions.SUM(log.value)'] == expected_values).values.all()
+
+
+def test_calc_feature_matrix_with_cutoff_df_and_instance_ids(es):
+    times = list([datetime(2011, 4, 9, 10, 30, i * 6) for i in range(5)] +
+                 [datetime(2011, 4, 9, 10, 31, i * 9) for i in range(4)] +
+                 [datetime(2011, 4, 9, 10, 40, 0)] +
+                 [datetime(2011, 4, 10, 10, 40, i) for i in range(2)] +
+                 [datetime(2011, 4, 10, 10, 41, i * 3) for i in range(3)] +
+                 [datetime(2011, 4, 10, 11, 10, i * 3) for i in range(2)])
+    instances = range(17)
+    cutoff_time = pd.DataFrame({'time': times, es['log'].index: instances})
+    labels = [False] * 3 + [True] * 2 + [False] * 9 + [True] + [False] * 2
+
+    property_feature = ft.Feature(es['log']['value']) > 10
+
+    match = "Passing 'instance_ids' is valid only if 'cutoff_time' is a single value or None - ignoring"
+    with pytest.warns(UserWarning, match=match):
+        feature_matrix = calculate_feature_matrix([property_feature],
+                                                  es,
+                                                  cutoff_time=cutoff_time,
+                                                  instance_ids=[1, 3, 5],
+                                                  verbose=True)
+
+    if isinstance(feature_matrix, dd.DataFrame):
+        feature_matrix = feature_matrix.compute()
+    assert (feature_matrix[property_feature.get_name()] == labels).values.all()
