@@ -10,9 +10,9 @@ from featuretools.primitives import Age, TimeSince
 def test_time_since():
     time_since = TimeSince()
     # class datetime.datetime(year, month, day[, hour[, minute[, second[, microsecond[,
-    times = [datetime(2019, 3, 1, 0, 0, 0, 1),
-             datetime(2019, 3, 1, 0, 0, 1, 0),
-             datetime(2019, 3, 1, 0, 2, 0, 0)]
+    times = pd.Series([datetime(2019, 3, 1, 0, 0, 0, 1),
+                       datetime(2019, 3, 1, 0, 0, 1, 0),
+                       datetime(2019, 3, 1, 0, 2, 0, 0)])
     cutoff_time = datetime(2019, 3, 1, 0, 0, 0, 0)
     values = time_since(array=times, time=cutoff_time)
 
@@ -34,9 +34,9 @@ def test_time_since():
     values = time_since(array=times, time=cutoff_time)
     assert(list(map(int, values)) == [0, 0, 0])
 
-    times_y = [datetime(2019, 3, 1, 0, 0, 0, 1),
-               datetime(2020, 3, 1, 0, 0, 1, 0),
-               datetime(2017, 3, 1, 0, 0, 0, 0)]
+    times_y = pd.Series([datetime(2019, 3, 1, 0, 0, 0, 1),
+                         datetime(2020, 3, 1, 0, 0, 1, 0),
+                         datetime(2017, 3, 1, 0, 0, 0, 0)])
 
     time_since = TimeSince(unit='Years')
     values = time_since(array=times_y, time=cutoff_time)
