@@ -214,4 +214,4 @@ def col_is_datetime(col):
 
 def replace_latlong_nan(values):
     """replace a single `NaN` value with a tuple: `(np.nan, np.nan)`"""
-    return np.where(values.isnull(), pd.Series([(np.nan, np.nan)] * len(values)), values)
+    return values.where(values.notnull(), pd.Series([(np.nan, np.nan)] * len(values)))
